@@ -203,6 +203,7 @@ class arg(Argument):
         bound: Union[omit, Tuple[int, int]] = omit,
         help : Union[omit, str] = omit,
         dest : Union[omit, str] = omit,
+        metavar : Optional[str] = None,
         group: Optional[str] = None,
     ) -> Argument:
         """
@@ -212,7 +213,7 @@ class arg(Argument):
         if bound is not arg.omit:
             lower, upper = bound
             nt = nt[lower:upper]
-        return arg(*args, group=group, help=help, dest=dest, type=nt, metavar='N')
+        return arg(*args, group=group, help=help, dest=dest, type=nt, metavar=metavar or 'N')
 
     @staticmethod
     def option(
@@ -289,20 +290,25 @@ class arg(Argument):
         default = pt.default
         guessed_pos_args = []
         guessed_kwd_args = dict(dest=pt.name, guess=True)
+        annotation = pt.annotation
 
-        if pt.annotation is not pt.empty:
-            if isinstance(pt.annotation, Argument):
-                if pt.annotation.kwargs.get('dest', pt.name) != pt.name:
+        if isinstance(annotation, str):
+            try: annotation = eval(annotation)
+            except Exception: pass
+
+        if annotation is not pt.empty:
+            if isinstance(annotation, Argument):
+                if annotation.kwargs.get('dest', pt.name) != pt.name:
                     raise ValueError(
                         F'Incompatible argument destination specified; parameter {pt.name} '
-                        F'was annotated with {pt.annotation!r}.')
-                guessed_pos_args = pt.annotation.args
-                guessed_kwd_args.update(pt.annotation.kwargs)
+                        F'was annotated with {annotation!r}.')
+                guessed_pos_args = annotation.args
+                guessed_kwd_args.update(annotation.kwargs)
                 guessed_kwd_args['guess'] = False
-                guessed_kwd_args['group'] = pt.annotation.group
-            elif isinstance(pt.annotation, type):
-                if not issubclass(pt.annotation, bool) and needs_type(guessed_kwd_args):
-                    guessed_kwd_args.update(type=get_argp_type(pt.annotation))
+                guessed_kwd_args['group'] = annotation.group
+            elif isinstance(annotation, type):
+                if not issubclass(annotation, bool) and needs_type(guessed_kwd_args):
+                    guessed_kwd_args.update(type=get_argp_type(annotation))
                 elif not isinstance(default, bool):
                     raise ValueError('Default value for boolean arguments must be provided.')
 
@@ -880,11 +886,10 @@ class Unit(metaclass=Executable, abstract=True):
 
         for last, chunk in lookahead(self):
             if (
-                self._framehandler.framebreak
-                or self._framehandler.unframed
+                not last
+                and (self._framehandler.unframed or self._framehandler.framebreak)
                 and not chunk.endswith(B'\n')
                 and not self.args.squeeze
-                and not last
             ):
                 chunk += B'\n'
             try:
@@ -1239,6 +1244,16 @@ class Unit(metaclass=Executable, abstract=True):
         # arguments passed to them (see PEP 468).
         self.args = DelayedArgumentProxy(Namespace(**keywords), list(keywords))
 
+    def detach(self):
+        """
+        When a unit is created using the `refinery.units.Unit.assemble` method, it is attached to a
+        logger by default (in less abstract terms, the `refinery.units.Unit.log_level` property is
+        set to a positive value). This method detaches the unit from its logger, which also means that
+        any exceptions that occur during runtime will be raised to the caller.
+        """
+        self.log_level = LogLevel.DETACHED
+        return self
+
     @classmethod
     def run(cls, argv=None, stream=None) -> None:
         """
@@ -1257,8 +1272,7 @@ class Unit(metaclass=Executable, abstract=True):
             except ArgparseError as ap:
                 ap.parser.error_commandline(str(ap))
             except Exception as msg:
-                raise
-                cls._output(F'initialization failed:', msg)
+                cls._output('initialization failed:', msg)
                 return
 
             try:
