@@ -7,7 +7,7 @@ try:
 except ModuleNotFoundError:
     Registry = None
 
-from . import PathExtractorUnit
+from . import PathExtractorUnit, UnpackResult
 
 
 class winreg(PathExtractorUnit):
@@ -20,14 +20,10 @@ class winreg(PathExtractorUnit):
             return
         for value in key.values():
             vpath = F'{here}/{value.name()}'
-            self.log_debug('crawl:', vpath)
-            matching = self._check_path(vpath)
-            if matching:
-                self.log_info('match:', vpath)
-                yield value.raw_data()
+            yield UnpackResult(vpath, lambda v=value: v.raw_data())
         for subkey in key.subkeys():
             yield from self._walk(subkey, *path, subkey.name())
 
-    def process(self, data):
+    def unpack(self, data):
         with io.BytesIO(data) as stream:
             yield from self._walk(Registry(stream).root())
