@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+from .. import arg
 from . import FrameSlicer
 
 
@@ -11,14 +12,10 @@ class scope(FrameSlicer):
     frame closes or the frame is being rescoped by a second application of
     this unit, they become visible again.
     """
-    @classmethod
-    def interface(cls, argp):
-        argp.add_argument('-n', '--not', dest='visible', action='store_false',
-            help='Hide the given chunks instead of making them the only ones visible.')
-        return super().interface(argp)
-
-    def __init__(self, *args, **kw):
-        super().__init__(*args, **kw)
+    def __init__(self, *slice, visible: arg.switch('-n', '--not', off=True, help=(
+        'Hide the given chunks instead of making them the only ones visible.')) = True
+    ):
+        super().__init__(*slice, visible=visible)
         # Sort any slices with negative arguments to the back so we check
         # them last. This delays potential consumption of the chunks iterator
         # as much as possible.
