@@ -11,5 +11,5 @@ class deob_ps1_escape(Deobfuscator):
     def deobfuscate(self, data):
         strlit = Ps1StringLiterals(data)
         @strlit.outside
-        def repl(m): return m.group(1)
+        def repl(m): return m[1]
         return re.sub(R'''`([^0abfnrtv`#'"\$])''', repl, data)
