@@ -1,16 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from .. import Unit
-from . import HexViewerMixin
+from . import HexViewer
 
 
-class hexview(Unit, HexViewerMixin):
+class hexview(HexViewer):
     """
     Produces a hex dump of the data.
     """
-
-    def interface(self, argp):
-        return super().interface(self.hexviewer_interface(argp))
+    def __init__(self, hexaddr=True, width=0, expand=False):
+        super().__init__(hexaddr=hexaddr, width=width, expand=expand)
 
     def process(self, data):
         for line in self.hexdump(data):
